/**
 * 验证非负整数（包含0及正整数）
 * @param {*} rule
 * @param {*} value
 * @param {*} callback
 */
export function checkNonnegativeInteger(rule, value, callback) {
  if (value) {
    value += ''
    if(/(^(0|[1-9][0-9]*)$)/.test(value)) {
      callback()
    } else {
      callback(new Error('只能输入数字,数值不能为负,且不能为小数'))
    }
  } else {
    callback()
  }
}

/**
 * 验证正整数（不包含0的正整数）
 * @param {*} rule
 * @param {*} value
 * @param {*} callback
 */
export function checkPositiveInteger(rule, value, callback) {
  if (value) {
    value += ''
    if(/(^[1-9]\d*$)/.test(value)) {
      callback()
    } else {
      callback(new Error('只能输入数字,数值不能为负数或0,且不能为小数'))
    }
  } else {
    callback()
  }
}

/**
 * 验证正数，且小数可2位（包含0及正整数）
 * @param {*} rule
 * @param {*} value
 * @param {*} callback
 */
export function checkPositiveDecimal(rule, value, callback) {
  if (value) {
    value += ''
    // if(/(^[1-9]([0-9]+)?(\.[0-9]{1,4})?$)|(^(0){1}$)|(^[0-9]\.[0-9]([0-9])?$)/.test(value)) {
    // if(/(^[1-9]([0-9]+)?(\.[0-9]{1,2})?$)|(^(0){1}$)|(^[0-9]\.[0-9]([0-9])?$)/.test(value)) {
    if(/(^[1-9]([0-9]+)?(\.[0-9]{1,2})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,2}$)/.test(value)) {
      callback()
    } else {
      callback(new Error('只能输入数字,且数值不能为负,小数限2位'))
    }
  } else {
    callback()
  }
}
/**
 * 验证正数，整数位数为6位，小数可2位（包含0及正整数）
 * @param {*} rule
 * @param {*} value
 * @param {*} callback
 */
export function checkBigdecimal(rule, value, callback) {
  if (value) {
    value += ''
    if(/^(\d{1,6})(\.\d{1,2})?$/.test(value)) {
      callback()
    } else {
      callback(new Error('只能输入数字,且数值不能为负,整数限6位,小数限2位'))
    }
  } else {
    callback()
  }
}
/**
 * 验证正数，且小数可4位（包含0及正整数）
 * @param {*} rule
 * @param {*} value
 * @param {*} callback
 */
export function checkPositiveDecimal4(rule, value, callback) {
  if (value) {
    value += ''
    // if(/(^[1-9]([0-9]+)?(\.[0-9]{1,4})?$)|(^(0){1}$)|(^[0-9]\.[0-9]([0-9]){0,3}$)/.test(value)) {
    if(/(^[1-9]([0-9]+)?(\.[0-9]{1,4})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,4}$)/.test(value)) {
      callback()
    } else {
      callback(new Error('只能输入数字,且数值不能为负,小数限4位'))
    }
  } else {
    callback()
  }
}

/**
 * 验证一位整数和一位小数
 * @param {*} rule
 * @param {*} value
 * @param {*} callback
 */
export function checkPositiveDecimal1(rule, value, callback) {
  if (value) {
    value += ''
    // if(/(^[1-9]([0-9]+)?(\.[0-9]{1,4})?$)|(^(0){1}$)|(^[0-9]\.[0-9]([0-9]){0,3}$)/.test(value)) {
    if( /(^[0-9]{1,1}$)|(^[0-9]{1,2}[\.]{1}[0-9]{1,1}$)/.test(value)) {
      callback()
    } else {
      callback(new Error('只能输入数字,且只有一位整数和一位小数'))
    }
  } else {
    callback()
  }
}

/**
 * 验证手机号，座机号
 * @param {*} rule
 * @param {*} value
 * @param {*} callback
 */
export function validPhoneMobile(rule, value, callback){
  if (value){
    if (value === '') {
      callback(new Error('请输入11位手机号'));
    } else {
      let regPone = null;
      let mobile = /^1(3|4|5|6|7|8|9)\d{9}$/; //最新16手机正则
      let tel = /^(0\d{2,3}-){0,1}\d{7,8}$/; //座机
      if (value.charAt(0) == 0) {    // charAt查找第一个字符方法，用来判断输入的是座机还是手机号
        regPone = tel;
      } else {
        regPone = mobile;
      }
      if (!regPone.test(value)) {
        callback(new Error("请填写11位手机号"))
      }
      callback();
    }
  }else {
    callback();
  }
}



/**
 * 英文和数字校验
 * @param rule
 * @param value
 * @param callback
 */
export function englishAndNumValid(rule, value, callback) {
  if (value) {
    value += ''
    if (value.match(/^[A-Za-z0-9]{4,40}$/)) {
      callback()
    } else {
      callback(new Error('只能输入英文和数字'))
    }
  } else {
    callback()
  }
}
/**
 * 英文和数字校验18位
 * @param rule
 * @param value
 * @param callback
 */
export function englishAndshibaNumValid(rule, value, callback) {
  if (value) {
    value += ''
    if (value.match(/^[A-Za-z0-9]{0,18}$/)) {
      callback()
    } else {
      callback(new Error('只能输入0~18位英文和数字'))
    }
  } else {
    callback()
  }
}

/**
 * 全英文校验
 * @param rule
 * @param value
 * @param callback
 */
export function englishValid(rule, value, callback) {
  if (value) {
    value += ''
    if (value.match( /^[A-Za-z]+$/)) {
      callback()
    } else {
      callback(new Error('只能输入英文'))
    }
  } else {
    callback()
  }
}

export function chineseValid(rule, value, callback) {
  if (value) {
    value += ''
    if (value.match(/^[\u4e00-\u9fa5]+$/)) {
      callback()
    } else {
      callback(new Error('只能输入中文'))
    }
  } else {
    callback()
  }
}





